# NanoSSO
[![PyPI](https://img.shields.io/pypi/v/NanoSSO)](https://pypi.org/project/NanoSSO)
[![Documentation Status](https://readthedocs.org/projects/nanosso/badge/?version=latest)](https://nanosso.nullsec.space/en/latest/?badge=latest)
[![NanoSSO](https://github.com/NullsecSpace/NanoSSO/actions/workflows/github-actions.yml/badge.svg)](https://github.com/NullsecSpace/NanoSSO/actions/workflows/github-actions.yml)
[![GitHub](https://img.shields.io/github/license/NullsecSpace/NanoSSO)](https://github.com/NullsecSpace/NanoSSO/blob/main/LICENSE)

A simple library for easily handling SSO for building tools that interact with
the [EVE Online ESI API](https://esi.evetech.net/ui).

- :books: Documentation: https://NanoSSO.nullsec.space
- :bulb: Examples: https://NanoSSO.nullsec.space/en/latest/examples/index.html

# Installation

```
pip install NanoSSO
```